@@ -108,21 +108,41 @@ named COPYING and dvipng.c.");
 	}
 	break ;
       case 't':       /* specify paper format, only for cropmarks */
-	/* cropmarks not implemented yet */
-	if (*p == 0 && argv[i+1])
-	  p = argv[++i] ;
-	if (strcmp(p,"a4")) {
-	  handlepapersize("210mm,297mm",&x_pwidth,&y_pwidth);
-	} else if (strcmp(p,"letter")) {
-	  handlepapersize("8.5in,11in",&x_pwidth,&y_pwidth);
-	} else if (strcmp(p,"legal")) {
-	  handlepapersize("8.5in,14in",&x_pwidth,&y_pwidth);
-	} else if (strcmp(p,"executive")) {
-	  handlepapersize("7.25in,10.5in",&x_pwidth,&y_pwidth);
+#if HAVE_GDIMAGECREATETRUECOLOR
+	/* Truecolor */
+	if (strncmp(p,"ruecolor",8)==0) { 
+	  truecolor = (p[9] != '0');
+	  if (truecolor)
+	    Message(PARSE_STDIN,"Truecolor mode on\n",p);
+	  else 
+	    Message(PARSE_STDIN,"Truecolor mode off\n");
 	} else 
-	  Fatal("The papersize %s is not implemented, sorry.\n",p);
-	Message(PARSE_STDIN,"Papersize: %s\n",p);
-        break;
+#endif
+	  { /* cropmarks not implemented yet */
+	    if (*p == 0 && argv[i+1])
+	      p = argv[++i] ;
+	    if (strcmp(p,"a4")==0) {
+	      handlepapersize("210mm,297mm",&x_pwidth,&y_pwidth);
+	    } else if (strcmp(p,"letter")==0) {
+	      handlepapersize("8.5in,11in",&x_pwidth,&y_pwidth);
+	    } else if (strcmp(p,"legal")==0) {
+	      handlepapersize("8.5in,14in",&x_pwidth,&y_pwidth);
+	    } else if (strcmp(p,"executive")==0) {
+	      handlepapersize("7.25in,10.5in",&x_pwidth,&y_pwidth);
+	    } else
+	      Fatal("The papersize %s is not implemented, sorry.\n",p);
+	    Message(PARSE_STDIN,"Papersize: %s\n",p);
+	  }
+	break;
+      case 'c':
+	if (strncmp(p,"acheimages",10)==0) { 
+	  cacheimages = (p[11] != '0');
+	  if (cacheimages)
+	    Message(PARSE_STDIN,"Caching images\n",p);
+	  else 
+	    Message(PARSE_STDIN,"Not caching images\n");
+	  break;
+	}
       case 'b':
 	if ( *p == 'g' ) { /* -bg background color */
 	  p++;
@@ -273,31 +293,34 @@ named COPYING and dvipng.c.");
     fprintf(stdout,"\nUsage: dvipng [OPTION]... FILENAME[.dvi]\n");
     fprintf(stdout,"Options are chosen to be similar to dvips' options where possible:\n");
 #ifdef DEBUG
-    fprintf(stdout,"  -d #      Debug (# is the debug bitmap, 1 if not given)\n");
+    fprintf(stdout,"  -d #       Debug (# is the debug bitmap, 1 if not given)\n");
 #endif
-    fprintf(stdout,"  -D #      Resolution\n");
-    fprintf(stdout,"  -M*       Don't make fonts\n");
-    fprintf(stdout,"  -l #      Last page to be output\n");
-    fprintf(stdout,"  -mode s   MetaFont mode (default cx)\n");
-    fprintf(stdout,"  -o f      Output file, '%%d' is pagenumber\n");
-    fprintf(stdout,"  -O c      Image offset\n");
-    fprintf(stdout,"  -p #      First page to be output\n");
-    fprintf(stdout,"  -pp #,#.. Page list to be output\n");
-    fprintf(stdout,"  -q*       Quiet operation\n");
-    fprintf(stdout,"  -r*       Reverse order of pages\n");
-    fprintf(stdout,"  -t c      Paper format (also accepts e.g., '-t a4')\n");
-    fprintf(stdout,"  -T c      Image size (also accepts '-T bbox' and '-T tight')\n");
-    fprintf(stdout,"  -v*       Verbose operation\n");
-    fprintf(stdout,"  -x #      Override dvi magnification\n");
-    fprintf(stdout,"  -         Interactive query of options\n");
+    fprintf(stdout,"  -D #       Resolution\n");
+    fprintf(stdout,"  -M*        Don't make fonts\n");
+    fprintf(stdout,"  -l #       Last page to be output\n");
+    fprintf(stdout,"  -mode s    MetaFont mode (default cx)\n");
+    fprintf(stdout,"  -o f       Output file, '%%d' is pagenumber\n");
+    fprintf(stdout,"  -O c       Image offset\n");
+    fprintf(stdout,"  -p #       First page to be output\n");
+    fprintf(stdout,"  -pp #,#..  Page list to be output\n");
+    fprintf(stdout,"  -q*        Quiet operation\n");
+    fprintf(stdout,"  -r*        Reverse order of pages\n");
+    fprintf(stdout,"  -t c       Paper format (also accepts e.g., '-t a4')\n");
+    fprintf(stdout,"  -T c       Image size (also accepts '-T bbox' and '-T tight')\n");
+    fprintf(stdout,"  -v*        Verbose operation\n");
+    fprintf(stdout,"  -x #       Override dvi magnification\n");
+    fprintf(stdout,"  -          Interactive query of options\n");
     fprintf(stdout,"\nThese do not correspond to dvips options:\n");
-    fprintf(stdout,"  -bd #     Transparent border width in dots\n");
-    fprintf(stdout,"  -bg s     Background color (TeX-style color)\n");
-    fprintf(stdout,"  -fg s     Foreground color (TeX-style color)\n");
-    fprintf(stdout,"  -follow   Follow mode\n");
-    fprintf(stdout,"  -Q #      Quality (~xdvi's shrinkfactor)\n");
+    fprintf(stdout,"  -bd #      Transparent border width in dots\n");
+    fprintf(stdout,"  -bg s      Background color (TeX-style color)\n");
+    fprintf(stdout,"  -fg s      Foreground color (TeX-style color)\n");
+    fprintf(stdout,"  -follow    Follow mode\n");
+#ifdef HAVE_GDIMAGECREATETRUECOLOR
+    fprintf(stdout,"  -truecolor Truecolor output\n");
+#endif
+    fprintf(stdout,"  -Q #       Quality (~xdvi's shrinkfactor)\n");
 #ifdef HAVE_GDIMAGEPNGEX
-    fprintf(stdout,"  -z #      PNG compression level\n");
+    fprintf(stdout,"  -z #       PNG compression level\n");
 #endif
     
     fprintf(stdout,"\n   # = number   f = file   s = string  * = suffix, '0' to turn off\n");
